@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11197 2018-08-06 09:55:55Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2018-08-06 18:55:55 +0900 (週一, 06 八月 2018) $
+# $Revision: 11197 $
 
 from __future__ import print_function
 
@@ -25,6 +25,8 @@ import importlib
 from .Patch import attachURLs, attachDebugURLs
 from .Util import update, populateEnvToSettings
 
+from Iuppiter.DjangoUtil import extendInstalledApps
+
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
 STAGE = 2
@@ -488,10 +490,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'LOGGING',
     ), settingsDict)
     #=========================================================================
-    defaultForwardedHost = {
-        'USE_X_FORWARDED_HOST': True
-    }
-    update(settingsDict, defaultForwardedHost)
 
     #=========================================================================
     # I18n.
@@ -568,6 +566,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'EMAIL_USE_TLS': True,
         'EMAIL_HOST_USER': "test@nuwainfo.com",
         'EMAIL_HOST_PASSWORD': "test25025529",
+        'EMAIL_BACKEND': 'Iuno.Email.ConfiguredEmailBackend',
     }
     
     update(settingsDict, emailDefaults)
@@ -591,12 +590,19 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     #=========================================================================
     
     #=========================================================================
-    # HTTPS.
+    # HTTPS and HTTP related options.    
     if 'SECURE_PROXY_SSL_HEADER' not in settingsDict:
         https = os.environ.get('HTTPS', None)
         if https == 'on':
             settingsDict['SECURE_PROXY_SSL_HEADER'] = (
                 'HTTP_X_FORWARDED_PROTO', 'https')
+
+    defaultHttpOptions = {
+        'USE_X_FORWARDED_HOST': True,
+        # Allow userTrack uses iframe to track user motion.
+        'X_FRAME_OPTIONS': "ALLOW-FROM https://session.nuwainfo.com/"
+    }
+    update(settingsDict, defaultHttpOptions)    
     #=========================================================================
 
     #=========================================================================
@@ -683,6 +689,14 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         warnWithout('INSTALLED_APPS', settingsDict, pluginsDefaults)
 
     update(settingsDict, pluginsDefaults)
+    # django-des
+    ADDING_INSTALLED_APPS = (
+        'des',
+    )
+    installed = settingsDict['INSTALLED_APPS']
+    keys = [k for k in installed if k.startswith('django.contrib')]
+    extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
+                        key=list(keys)[-1])
     #=========================================================================
 
     #=========================================================================
