@@ -3,7 +3,7 @@
 if [ -z $VIRTUAL_ENV ]; then
     virtualenv env
     source env/bin/activate
-    python -m pip install --upgrade pip==8.1.1
+    python -m pip install --upgrade pip
     pip install -r REQUIREMENTS.txt
 fi
 
