@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11168 2018-07-15 02:38:28Z Lavender $
+# $Id: __init__.py 11196 2018-08-06 09:02:05Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-15 11:38:28 +0900 (週日, 15 七月 2018) $
-# $Revision: 11168 $
+# $Date: 2018-08-06 18:02:05 +0900 (週一, 06 八月 2018) $
+# $Revision: 11196 $
 
 import os
 import sys
@@ -244,6 +244,26 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
 
     #=========================================================================
+    ecpayEnable = False
+    if 'IUNO_SHOP_ECPAY_ENABLE' in settingsDict:
+        ecpayEnable = settingsDict['IUNO_SHOP_ECPAY_ENABLE']
+
+    allpayEnable = False
+    if 'IUNO_SHOP_ALLPAY_ENABLE' in settingsDict:
+        allpayEnable = settingsDict['IUNO_SHOP_ALLPAY_ENABLE']
+
+    spgatewayEnable = False
+    if 'IUNO_SHOP_SPGATEWAY_ENABLE' in settingsDict:
+        spgatewayEnable = settingsDict['IUNO_SHOP_SPGATEWAY_ENABLE']
+
+    ADDING_OSCAR_DASHBOARD_NAVIGATION = {
+        'label': _('Payment'),
+        'icon': 'icon-globe',
+        'children': [
+           
+        ]
+    }
+
     if enablePaypal:
         require('PAYPAL_API_USERNAME', settingsDict)
         require('PAYPAL_API_PASSWORD', settingsDict)
@@ -261,20 +281,40 @@ def attachSettings(settingsDict, enablePaypal=False):
         }
         update(settingsDict, ADDING_OSCAR_SHOP_TAGLINE)
 
-        ADDING_OSCAR_DASHBOARD_NAVIGATION = {
-            'label': _('PayPal'),
-            'icon': 'icon-globe',
-            'children': [
-                {
-                    'label': _('Express transactions'),
-                    'url_name': 'paypal-express-list',
-                },
-            ]
-        }
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('Paypal transactions'),
+            'url_name': 'paypal-express-list',
+        })
+
+    if ecpayEnable:
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('ECPay transactions'),
+            'url_name': 'ecpayTransaction',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+        })
+    if allpayEnable:
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('AllPay transactions'),
+            'url_name': 'allpayTransaction',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+        })
+    if spgatewayEnable:
+        ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
+            'label': _('Spgateway transactions'),
+            'url_name': 'spgatewayTransaction',
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
+        })
+
+    if enablePaypal or ecpayEnable or allpayEnable or spgatewayEnable:
         if 'OSCAR_DASHBOARD_NAVIGATION' in settingsDict:
-            settingsDict['OSCAR_DASHBOARD_NAVIGATION'].append(ADDING_OSCAR_DASHBOARD_NAVIGATION)
+            settingsDict['OSCAR_DASHBOARD_NAVIGATION'].append(
+                ADDING_OSCAR_DASHBOARD_NAVIGATION)
         else:
-            settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = ADDING_OSCAR_DASHBOARD_NAVIGATION
+            settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = \
+                                            ADDING_OSCAR_DASHBOARD_NAVIGATION
     #=========================================================================
     
     #=========================================================================
@@ -295,9 +335,12 @@ def attachShopURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
+    from Iuno.shop import views
 
     from django.conf.urls import url, patterns, include
+    from django.contrib.admin.views.decorators import staff_member_required
     from oscar.app import application as shop
+    from paypal.express.dashboard.app import application
     
     urlpatterns += patterns('',
         # the i18n is the default url settings of django oscar, but generally
@@ -306,28 +349,56 @@ def attachShopURLs(settings, urlpatterns):
         (r'^shop/', shop.urls),
     )
 
-def attachPaypalURLs(settings, urlpatterns):
-    """
-    Attach paypal related urlpatterns.
-    It must be called in urls.py by passing urlpatterns.
- 
-    @param settings Django project's settings module.
-    @param urlpatterns urlpatterns in urls.py.
-    """
-    from Iuno.shop import views
+    paypalEnable = False
+    if hasattr(settings, 'IUNO_SHOP_PAYPAL_ENABLE'):
+        paypalEnable = settings.IUNO_SHOP_PAYPAL_ENABLE
+    
+    ecpayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ECPAY_ENABLE'):
+        ecpayEnable = settings.IUNO_SHOP_ECPAY_ENABLE
 
-    from django.conf.urls import url, patterns, include
-    from paypal.express.dashboard.app import application
+    allpayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ALLPAY_ENABLE'):
+        allpayEnable = settings.IUNO_SHOP_ALLPAY_ENABLE
 
-    urlpatterns += patterns('',
-        
-        url(r'^shop/dashboard/paypal/express/', application.urls),
-        url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
-            views.SuccessResponseView.as_view(), name='paypal-place-order'),
-        url(r'^checkout/paypal/', include('paypal.express.urls')),
+    spgatewayEnable = False
+    if hasattr(settings, 'IUNO_SHOP_SPGATEWAY_ENABLE'):
+        spgatewayEnable = settings.IUNO_SHOP_SPGATEWAY_ENABLE
 
-        url(r'^(?P<name>.*)/preview/', views.SuccessResponseView2.as_view()),
-    )
+    if paypalEnable:
+        urlpatterns += patterns('',          
+            url(r'^shop/dashboard/paypal/express/', application.urls),
+            url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
+                views.SuccessResponseView.as_view(), name='paypal-place-order'),
+            url(r'^checkout/paypal/', include('paypal.express.urls')),
+        )
+
+    if ecpayEnable or allpayEnable or spgatewayEnable:
+        urlpatterns += patterns('',
+            url(r'^(?P<name>.*)/preview/', 
+                views.SuccessResponseView2.as_view()),
+        )
+    if ecpayEnable:
+        urlpatterns += patterns('',
+            url(r'^dashboard/ecpay/transaction/', 
+                staff_member_required(
+                    views.ECPayTransactionListView.as_view()),
+                name='ecpayTransaction'),
+        )
+    if allpayEnable:
+        urlpatterns += patterns('',
+            url(r'^dashboard/allpay/transaction/', 
+                staff_member_required(
+                    views.AllPayTransactionListView.as_view()),
+                name='allpayTransaction'),
+        )
+    if spgatewayEnable:
+        urlpatterns += patterns('',
+            url(r'^dashboard/spgateway/transaction/', 
+                staff_member_required(
+                    views.SpgatewayTransactionListView.as_view()),
+                name='spgatewayTransaction'),
+        )
 
 # ------------------------------------------------------------------------------
 import hashlib
@@ -337,6 +408,7 @@ import datetime
 from django.conf import settings
 from django.template.loader import get_template
 from django.template import Context
+from django.utils.translation import ugettext_lazy as _
 from pyallpay import AllPay
 
 from Iuppiter.Encoding import utf8
@@ -354,6 +426,30 @@ SPGATEWAY = 'spgateway'
 ALLPAY = 'allpay'
 ECPAY = 'ecpay'
 
+class AllPay2(AllPay):
+    def gen_check_out_form(self, dict_url, auto_send=True):
+        """
+        Generate The Form Submission
+        :param dict_url:
+        :return: the html of the form
+        """
+        form_html = utf8(
+            ('<form id="allPay-Form" name="allPayForm" method="post" '
+             'target="_self" action="%s" style="display: none;">') % 
+             self.service_url)
+
+        for i, val in enumerate(dict_url):
+            form_html += utf8(
+                "<input type='hidden' name='%s' value='%s' />" % (
+                    val, dict_url[val]))
+
+        form_html  += utf8(
+            '<input type="submit" class="large" '
+            'id="payment-btn" value="BUY" /></form>')
+        if auto_send:
+            form_html += utf8("<script>document.allPayForm.submit();</script>")
+        return form_html
+
 def buildAPIForm(submission, request, apiName):
     scheme = request.scheme
     domain = request.META['HTTP_HOST']
@@ -367,15 +463,18 @@ def buildAPIForm(submission, request, apiName):
     basket = submission['basket']
     
     # item name
-    itemName = u''
+    itemName = utf8('')
     for index, line in enumerate(basket.all_lines()):
         product = line.product
         productName = product.get_title()
         itemName += utf8(productName)
         
-        itemName += u' %d dollar X %d#' % (line.price_excl_tax, line.quantity)
-    itemName += (u"shipping charge %d dollar X 1" % 
-                 submission['shipping_charge'].excl_tax)
+        itemName += utf8(_(' %(dollar)d dollar X %(number)d#') % {
+                    'dollar': line.price_excl_tax, 'number': line.quantity})
+    itemName += utf8(_("shipping charge %(dollar)d dollar X 1") % {
+                     'dollar': submission['shipping_charge'].excl_tax})
+
+    itemName = utf8(itemName)
     
     # merchantTradeNo
     basketId = basket.id
@@ -420,7 +519,7 @@ def buildAPIForm(submission, request, apiName):
         payment = mpg.createPayment(data)
         context = Context({'spgateway': payment,})
 
-        temp = get_template('shop/Payment/Spgateway.html')
+        temp = get_template('shop/payment/Spgateway.html')
         form = temp.render(context)
                                       
         return form
@@ -435,7 +534,7 @@ def buildAPIForm(submission, request, apiName):
             'Remark' : settings.OSCAR_SHOP_NAME,
         }
 
-        ap = AllPay(data)
+        ap = AllPay2(data)
 
         if apiName == ECPAY:
             if settings.ECPAY_SANDBOX_MODE:
@@ -467,12 +566,12 @@ def buildAPIForm(submission, request, apiName):
         if apiName == ECPAY:
             form = ap.gen_check_out_form(dictUrl, 
                                     settings.ECPAY_AUTO_SEND_FORM)
-            form = form.replace(u'allPay-Form', u'ecpayForm')
-            form = form.replace(u'allPayForm', u'ecpayForm')
+            form = form.replace('allPay-Form', 'ecpayForm')
+            form = form.replace('allPayForm', 'ecpayForm')
         else:
             form = ap.gen_check_out_form(dictUrl, 
                                     settings.ALLPAY_AUTO_SEND_FORM)
-            form = form.replace(u'allPay-Form', u'allpayForm')
-            form = form.replace(u'allPayForm', u'allpayForm')
+            form = form.replace('allPay-Form', 'allpayForm')
+            form = form.replace('allPayForm', 'allpayForm')
         
         return form
\ No newline at end of file
