@@ -37,3 +37,17 @@ class AllPayTrade(models.Model):
     paymentType = models.CharField(max_length=30)
     simulatePaid = models.CharField(max_length=30)
     paymentTypeChargeFee = models.CharField(max_length=30)
+
+class SpgatewayTrade(models.Model):
+    merchantId = models.CharField(max_length=30)
+    merchantTradeNo = models.CharField(max_length=30)
+    tradeNo = models.CharField(max_length=30)
+    
+    paymentDate = models.DateTimeField()
+    
+    paymentType = models.CharField(max_length=30)
+    paymentMethod = models.CharField(max_length=30)
+    tradeAmt = models.IntegerField()
+         
+    rtnCode = models.CharField(max_length=30)
+    rtnMsg = models.CharField(max_length=30)
